@@ -4,6 +4,7 @@ from contextlib import contextmanager
 import inspect
 import json
 from os.path import splitext
+import re
 from typing import List
 from urllib.parse import urlparse
 
@@ -32,6 +33,7 @@ from myst_parser.mocking import (
     MockIncludeDirective,
 )
 from .parse_directives import parse_directive_text, DirectiveParsingError
+from .parse_html import HTMLImgParser
 
 
 def make_document(source_path="notset") -> nodes.document:
@@ -40,6 +42,29 @@ def make_document(source_path="notset") -> nodes.document:
     return new_document(source_path, settings=settings)
 
 
+# CSS class regex taken from https://www.w3.org/TR/CSS21/syndata.html#characters
+REGEX_ADMONTION = re.compile(
+    r"\{(?P<name>[a-zA-Z]+)(?P<classes>(?:\,-?[_a-zA-Z]+[_a-zA-Z0-9-]*)*)\}(?P<title>.*)"  # noqa: E501
+)
+STD_ADMONITIONS = {
+    "attention": nodes.attention,
+    "caution": nodes.caution,
+    "danger": nodes.danger,
+    "error": nodes.error,
+    "important": nodes.important,
+    "hint": nodes.hint,
+    "note": nodes.note,
+    "tip": nodes.tip,
+    "warning": nodes.warning,
+}
+try:
+    from sphinx import addnodes
+
+    STD_ADMONITIONS["seealso"] = addnodes.seealso
+except ImportError:
+    pass
+
+
 class DocutilsRenderer:
     __output__ = "docutils"
 
@@ -413,7 +438,7 @@ class DocutilsRenderer:
         # If there's not a url scheme (e.g. 'https' for 'https:...' links),
         # or there is a scheme but it's not in the list of known_url_schemes,
         # then assume it's a cross-reference
-        known_url_schemes = self.config.get("known_url_schemes", None)
+        known_url_schemes = self.config.get("myst_url_schemes", None)
         if known_url_schemes:
             scheme_known = url_check.scheme in known_url_schemes
         else:
@@ -444,7 +469,12 @@ class DocutilsRenderer:
         self.current_node.append(nodes.raw("", token.content, format="html"))
 
     def render_html_block(self, token):
-        self.current_node.append(nodes.raw("", token.content, format="html"))
+        node = None
+        if self.config.get("myst_html_img", False):
+            node = HTMLImgParser().parse(token.content, self.document, token.map[0])
+        if node is None:
+            node = nodes.raw("", token.content, format="html")
+        self.current_node.append(node)
 
     def render_image(self, token):
         img_node = nodes.image()
@@ -622,6 +652,50 @@ class DocutilsRenderer:
             problematic = inliner.problematic(text, rawsource, message)
             self.current_node += problematic
 
+    def get_admonition(self, token, name, classes, title):
+
+        line = token.map[0]
+
+        if name == "admonition":
+            # parse title
+            node = nodes.admonition(title, classes=classes[1:].split(","))
+            state_machine = MockStateMachine(self, line)
+            state = MockState(self, state_machine, line)
+            textnodes, messages = state.inline_text(title, line)
+            title_node = nodes.title(title, "", *textnodes)
+            self.add_line_and_source_path(title_node, token)
+            node += title_node
+            node += messages
+            return node
+
+        node_cls = STD_ADMONITIONS.get(name, None)
+        if node_cls is None:
+            self.current_node.append(
+                self.reporter.warning(
+                    f"admonition name not recognised, defaulting to note: {name}",
+                    line=line,
+                )
+            )
+            node_cls = nodes.note
+        return node_cls(title, classes=classes[1:].split(","))
+
+    def render_container_admonition_open(self, token):
+        match = REGEX_ADMONTION.match(token.info.strip())
+        if not match:
+            self.current_node.append(
+                self.reporter.warning(
+                    "admonition argument did not match required regex, "
+                    f"defaulting to note: {token.info}",
+                    line=token.map[0],
+                )
+            )
+            admonition = nodes.note("")
+        else:
+            admonition = self.get_admonition(token, **match.groupdict())
+        self.add_line_and_source_path(admonition, token)
+        with self.current_node_context(admonition, append=True):
+            self.render_children(token)
+
     def render_directive(self, token: Token):
         """Render special fenced code blocks as directives."""
         first_line = token.info.split(maxsplit=1)
